# SPDX-FileCopyrightText: 2023 Daniel Wolf <nephatrine@gmail.com>
#
# SPDX-License-Identifier: ISC

set(CMAKE_SYSTEM_NAME "Darwin")

string(REPLACE "." ";" OSX_SDK_VERSION "$ENV{DARWIN_SDK}")
list(GET OSX_SDK_VERSION 0 OSX_SDK_MAJOR)
list(GET OSX_SDK_VERSION 1 CMAKE_SYSTEM_VERSION)

if(OSX_SDK_MAJOR EQUAL 10)
	math(EXPR CMAKE_SYSTEM_VERSION "${CMAKE_SYSTEM_VERSION} + 4")
elseif(OSX_SDK_MAJOR GREATER 10)
	math(EXPR CMAKE_SYSTEM_VERSION "${CMAKE_SYSTEM_VERSION} + 1")
	math(EXPR _nVerMajor "${OSX_SDK_MAJOR} + 9")
	set(CMAKE_SYSTEM_VERSION "${_nVerMajor}.${CMAKE_SYSTEM_VERSION}")
else()
	message(FATAL_ERROR "BAD OSX SDK VERSION")
endif()

unset(lsArchitectures)
if(CMAKE_SYSTEM_VERSION VERSION_LESS 18)
	list(APPEND lsArchitectures "i386")
	set(CMAKE_SYSTEM_PROCESSOR "i386")
endif()
if(CMAKE_SYSTEM_VERSION VERSION_LESS 20)
	list(APPEND lsArchitectures "x86_64")
	set(CMAKE_SYSTEM_PROCESSOR "x86_64")
endif()
if(CMAKE_SYSTEM_VERSION VERSION_GREATER_EQUAL 12)
	list(APPEND lsArchitectures "x86_64h")
	set(CMAKE_SYSTEM_PROCESSOR "x86_64h")
endif()
if(CMAKE_SYSTEM_VERSION VERSION_GREATER_EQUAL 20)
	list(APPEND lsArchitectures "arm64")
	set(CMAKE_SYSTEM_PROCESSOR "aarch64")
endif()

if(NOT DEFINED CMAKE_OSX_ARCHITECTURES)
	set(CMAKE_OSX_ARCHITECTURES "${lsArchitectures}" CACHE INTERNAL "Fat Architectures")
endif()

list(GET CMAKE_OSX_ARCHITECTURES -1 triplet)
set(triplet "${triplet}-apple-darwin${CMAKE_SYSTEM_VERSION}")

set(CMAKE_OSX_SYSROOT "$ENV{DARWIN_SYSROOT}")
list(APPEND CMAKE_FIND_ROOT_PATH "/opt/local")
list(APPEND CMAKE_PREFIX_PATH "$ENV{DARWIN_TOOLCHAIN}")

find_program(CMAKE_C_COMPILER NAMES "${triplet}-clang")
find_program(CMAKE_CXX_COMPILER NAMES "${triplet}-clang++")
find_program(CMAKE_OBJC_COMPILER NAMES "${triplet}-clang")
find_program(CMAKE_OBJCXX_COMPILER NAMES "${triplet}-clang++")

find_program(CMAKE_AR NAMES "${triplet}-ar")
find_program(CMAKE_RANLIB NAMES "${triplet}-ranlib")
find_program(CMAKE_STRIP NAMES "${triplet}-strip")
find_program(CMAKE_LINKER NAMES "${triplet}-ld")
find_program(CMAKE_NM NAMES "${triplet}-nm")
find_program(CMAKE_INSTALL_NAME_TOOL NAMES "${triplet}-install_name_tool")

set(CMAKE_FIND_ROOT_PATH_MODE_PROGRAM NEVER)
set(CMAKE_FIND_ROOT_PATH_MODE_LIBRARY ONLY)
set(CMAKE_FIND_ROOT_PATH_MODE_INCLUDE ONLY)
set(CMAKE_FIND_ROOT_PATH_MODE_PACKAGE ONLY)
