# SPDX-FileCopyrightText: 2023 Daniel Wolf <nephatrine@gmail.com>
#
# SPDX-License-Identifier: ISC

set(CMAKE_SYSTEM_NAME "Darwin")
set(CMAKE_SYSTEM_PROCESSOR "x86_64")
set(CMAKE_OSX_ARCHITECTURES "x86_64")
set(CMAKE_SIZEOF_VOID_P 8)

string(REPLACE "." ";" OSX_SDK_VERSION "$ENV{DARWIN_SDK}")
list(GET OSX_SDK_VERSION 0 OSX_SDK_MAJOR)
list(GET OSX_SDK_VERSION 1 CMAKE_SYSTEM_VERSION)

if(OSX_SDK_MAJOR EQUAL 10)
	math(EXPR CMAKE_SYSTEM_VERSION "${CMAKE_SYSTEM_VERSION} + 4")
elseif(OSX_SDK_MAJOR GREATER 10)
	math(EXPR CMAKE_SYSTEM_VERSION "${CMAKE_SYSTEM_VERSION} + 1")
	math(EXPR _nVerMajor "${OSX_SDK_MAJOR} + 9")
	set(CMAKE_SYSTEM_VERSION "${_nVerMajor}.${CMAKE_SYSTEM_VERSION}")
else()
	message(FATAL_ERROR "BAD OSX SDK VERSION")
endif()
if(CMAKE_SYSTEM_VERSION VERSION_GREATER_EQUAL 18)
	set(CMAKE_SYSTEM_PROCESSOR "x86_64h")
	set(CMAKE_OSX_ARCHITECTURES "x86_64h")
endif()

set(triplet "${CMAKE_SYSTEM_PROCESSOR}-apple-darwin${CMAKE_SYSTEM_VERSION}")

set(CMAKE_OSX_SYSROOT "$ENV{DARWIN_SYSROOT}")
list(APPEND CMAKE_FIND_ROOT_PATH "/opt/local")
list(APPEND CMAKE_PREFIX_PATH "$ENV{DARWIN_TOOLCHAIN}")

find_program(CMAKE_C_COMPILER NAMES "${triplet}-clang")
find_program(CMAKE_CXX_COMPILER NAMES "${triplet}-clang++")
find_program(CMAKE_OBJC_COMPILER NAMES "${triplet}-clang")
find_program(CMAKE_OBJCXX_COMPILER NAMES "${triplet}-clang++")

find_program(CMAKE_AR NAMES "${triplet}-ar")
find_program(CMAKE_RANLIB NAMES "${triplet}-ranlib")
find_program(CMAKE_STRIP NAMES "${triplet}-strip")
find_program(CMAKE_LINKER NAMES "${triplet}-ld")
find_program(CMAKE_NM NAMES "${triplet}-nm")
find_program(CMAKE_INSTALL_NAME_TOOL NAMES "${triplet}-install_name_tool")

set(CMAKE_LIBRARY_ARCHITECTURE "${triplet}")
set(CMAKE_C_LIBRARY_ARCHITECTURE "${CMAKE_LIBRARY_ARCHITECTURE}")
set(CMAKE_CXX_LIBRARY_ARCHITECTURE "${CMAKE_LIBRARY_ARCHITECTURE}")
set(CMAKE_OBJC_LIBRARY_ARCHITECTURE "${CMAKE_LIBRARY_ARCHITECTURE}")
set(CMAKE_OBJCXX_LIBRARY_ARCHITECTURE "${CMAKE_LIBRARY_ARCHITECTURE}")
set(CMAKE_ASM_LIBRARY_ARCHITECTURE "${CMAKE_LIBRARY_ARCHITECTURE}")

set(CMAKE_C_COMPILER_TARGET ${triplet})
set(CMAKE_CXX_COMPILER_TARGET ${triplet})
set(CMAKE_OBJC_COMPILER_TARGET "${triplet}")
set(CMAKE_OBJCXX_COMPILER_TARGET "${triplet}")
set(CMAKE_ASM_COMPILER_TARGET "${triplet}")

set(CMAKE_FIND_ROOT_PATH_MODE_PROGRAM NEVER)
set(CMAKE_FIND_ROOT_PATH_MODE_LIBRARY ONLY)
set(CMAKE_FIND_ROOT_PATH_MODE_INCLUDE ONLY)
set(CMAKE_FIND_ROOT_PATH_MODE_PACKAGE ONLY)
